/*=============================================================================
*                                                                             *
*    FILE NAME: CFRAPI26.H                                                    *
*                                                                             *
*    COPYRIGHT: IBM 7526 CFR API include file                                 *
*               (C) Copyright IBM Corporation 1992, 1996                      *
*               Licensed Material - Program property of IBM Corp.             *
*                                                                             *
*               Note to US Government users - Documentation related           *
*               to restricted rights - Use, duplication, or                   *
*               disclosure is subject to restrictions set forth in            *
*               GSA Schedule Contract with IBM Corporation.                   *
*                                                                             *
*    PURPOSE:   This module contains the C Language API function              *
*               prototypes, constant definitions and type                     *
*               definitions for inclusion in 7526 CFR's.                      *
*                                                                             *
*    Version:   3.02 (this module will also work with V1.01, 1.02, and 1.03,  *
*                     and 2.x as long as serial port calls are not used)      *
*                    GetDCTInfo is for Flash 4.24 and up.                     *
*                    TimerGetTicks and TimerResetTicks are in 4.25+,          *
*                    3.12 and higher EVEN numbers, 3.15+ ODD numbers.         *
*                                                                             *
*    PROCESSOR/COMPILER: IBM C/2 Compiler                                     *
*                                                                             *
=============================================================================*/

#define V101   1
#define V102   2
#define V103   3
#define V104   4
#define V200   5
#define V300   6


/*=============================================================================
*                                                                             *
* The following CFR API parameter type definitions must be included and used  *
* by the CFR writer to ensure proper type matching between microcode and      *
* CFR data items.                                                             *
*                                                                             *
=============================================================================*/

#define FAR   far
#define VOID  void
#define CHAR  char
#define SHORT short
#define INT   int

typedef unsigned char   BOOL;
typedef unsigned char   UCHAR;
typedef unsigned char   uchar;
typedef unsigned short  USHORT;
typedef unsigned short  ushort;
typedef unsigned long   ULONG;

typedef SHORT  FAR *PSHORT;
typedef UCHAR  FAR *PUCHAR;
typedef USHORT FAR *PUSHORT;
typedef ULONG  FAR *PULONG;


/******************************************************************************/
/*                                                                            */
/* The following function prototypes define the microcode functions which may */
/* be called from a 7526 CFR.                                                 */
/*                                                                            */
/******************************************************************************/


/******************************************************************************/
/* Retrieve Operating Information for 7526                                    */
/* For non-Ethernet 7526s, IP addresses are returned empty, ucPhyAddrress is  */
/* not set, and ucUnsolicitedOK is always 0.
/******************************************************************************/

struct DCT_Info
 {

  UCHAR ucHostOffline;      /* Host active  Offline   0 if active, 1 if offline */
                            /* This is usually not as reliable or easy to use as*/
                            /* the buffered transaction count below.            */
  UCHAR ucUnsolicitedOK;    /* Host has told us we can send unsolicited txns (1)*/
                            /* or we have been told not to (0).                 */
  UCHAR szDCTIPAddress[16]; /* String with DCT's IP address                     */
  UCHAR szDCCIPAddress[16]; /* String with DCC server's IP address              */
                            /* (server we are currently corresponding with)     */
  USHORT usTxnsInBuffer;    /* How many transactions are in the buffer          */
  UCHAR ucPhyAddr[6];       /* Address like 00 04 ac 93 00 16, binary without   */
                            /* a NULL terminator                                */
  ULONG ulBufferEmpty;      /* How many bytes of the transaction buffer are     */
                            /* currently empty.                                 */
 };



USHORT FAR GetDCTInfo (struct DCT_Info * );


/* Returns E_INTERNAL is run on a 7526 with no Ethernet adapter or prior to     */
/* B4.24 FLASH-ware.                                                            */
/* Example: (sprintf_752x is from the sample CFR26LIB.LIB library)

       struct DCT_Info sDCTInfo;
       char   buf[81];

       GetDCTInfo( &sDCTInfo );

       sprintf_752x( buf, 81, 0, 0, "Talking to %s, %u txns buffered.", 
                                      sDCTInfo.szDCCIPAddress, sDCTInfo.usTxnsInBuffer );

*/


/******************************************************************************/
/* DI-DO Interrupt Function Prototypes                                        */
/******************************************************************************/
USHORT FAR DiCtrRead (UCHAR, PULONG);
USHORT FAR DiCtrWrite (UCHAR, ULONG);
USHORT FAR DidoRead (PUCHAR);
USHORT FAR DidoWrite (UCHAR);
USHORT FAR DoWritePoint (UCHAR, UCHAR, UCHAR);

/******************************************************************************/
/* Keyboard Interrupt Function Prototypes                                     */
/******************************************************************************/
USHORT FAR KbdReadAscii (PUSHORT);
USHORT FAR KbdSetMode (UCHAR, UCHAR, UCHAR);

/******************************************************************************/
/* Real Time Clock Interrupt Function Prototypes                              */
/******************************************************************************/
USHORT FAR RtcGetAsciiDate (UCHAR, PUCHAR, PUCHAR);
USHORT FAR RtcGetAsciiTime (UCHAR, PUCHAR, PUCHAR);

/******************************************************************************/
/* Sensor Port and Speaker Interrupt Function Prototypes                      */
/******************************************************************************/
USHORT FAR SenActLed (UCHAR, UCHAR);
USHORT FAR SenSetDiscrimGrp (UCHAR, UCHAR);
USHORT FAR SenRead (PUCHAR, USHORT);
USHORT FAR SenQueryPort (PUCHAR);
USHORT FAR SenQueryPort2 (PUCHAR, PUCHAR);
USHORT FAR SpkBeep (UCHAR, USHORT);

/******************************************************************************/
/* LCD Display Function Prototypes                                            */
/******************************************************************************/
USHORT FAR VioClear (VOID);
USHORT FAR VioGetCurPos (PUCHAR, PUCHAR);
USHORT FAR VioQuery (PUCHAR, PUCHAR, PUCHAR, PUCHAR, PUCHAR);
USHORT FAR VioReadCharStr (PUCHAR, USHORT, UCHAR, UCHAR, PUSHORT, UCHAR);
USHORT FAR VioSetCurPos (UCHAR, UCHAR);
USHORT FAR VioWrtCharStr (PUCHAR, USHORT, UCHAR, UCHAR, PUSHORT, UCHAR);
USHORT FAR VioSetCurType (UCHAR);

/******************************************************************************
* General Support Function Prototypes                                         *
******************************************************************************/
USHORT FAR HitWatchdog (VOID);                         /* ah = 0             */
USHORT FAR DataFile (PUCHAR, PUCHAR FAR *, PULONG);    /* ah = 1             */
USHORT FAR PntrFile0 (PUCHAR FAR *);                   /* ah = 2             */
USHORT FAR ReadUserVariable (UCHAR, PUCHAR);           /* ah = 3             */
USHORT FAR ReadUserVariable2 (USHORT, PUCHAR);         /* ah = 12            */
USHORT FAR SendTransaction (VOID);                     /* ah = 4             */
USHORT FAR Validation (PUCHAR, PUCHAR);                /* ah = 5             */
USHORT FAR WriteToTrans (PUCHAR);                      /* ah = 6             */
USHORT FAR WriteUserVariable (UCHAR, PUCHAR);          /* ah = 7             */
USHORT FAR WriteUserVariable2 (USHORT, PUCHAR);        /* ah = 13            */
USHORT FAR AliasTransID (UCHAR);                       /* ah = 8             */
USHORT FAR IdleManager (USHORT);                       /* ah = 9             */
USHORT FAR ClearUserVariable (UCHAR);                  /* ah = 10            */
USHORT FAR ClearUserVariable2 (USHORT);                /* ah = 14            */
USHORT FAR GetTerminalAddress (PUCHAR);                /* ah = 11            */

/******************************************************************************/
/* Printer Support Function Prototypes                                        */
/******************************************************************************/
USHORT FAR PrtChar      (UCHAR);
USHORT FAR PrtInit      (VOID);
USHORT FAR PrtQuery     (PUSHORT, PUSHORT);
USHORT FAR PrtQueryData (PUSHORT, PUSHORT);
USHORT FAR PrtSetBuffer (PUCHAR, USHORT);
USHORT FAR PrtSetStatus (UCHAR);
USHORT FAR PrtStr       (PUCHAR, USHORT);

/******************************************************************************/
/* Timer Support Function Prototypes                                          */
/******************************************************************************/
USHORT FAR TimerSetAlarm         (struct timer_alarms *, USHORT);
USHORT FAR TimerClearAlarm       (VOID);
USHORT FAR TimerSetInterval      (struct timer_intervals *, USHORT);
USHORT FAR TimerClearInterval    (VOID);
USHORT FAR TimerSetAlarmAsynch   (struct timer_alarms_asynch *, USHORT);
USHORT FAR TimerClearAlarmAsynch (VOID);
USHORT FAR TimerGetTicks         (USHORT *);   /*  Returns current value of the
                                                *  free-wheeling 16-bit counter.
                                                *  Each tick is 5mS, +/- 10%.
                                                */
USHORT FAR TimerResetTicks       (VOID);       /* Reset 5mS ticker to 0        */

/******************************************************************************/
/* Serial Port Support Function Prototypes                                    */
/******************************************************************************/
USHORT FAR ComRead(UCHAR, USHORT, UCHAR *, USHORT *);
USHORT FAR ComWrite(UCHAR, USHORT, UCHAR  *, USHORT *);
USHORT FAR ComInit(UCHAR, UCHAR, UCHAR, UCHAR, UCHAR);
USHORT FAR ComQuery(UCHAR, UCHAR *);
USHORT FAR ComGetMdmCtl(UCHAR, UCHAR *);
USHORT FAR ComSetMdmCtl(UCHAR, UCHAR);

/******************************************************************************/
/*                                                                            */
/* The following definitions are the possible return codes for the 7526       */
/* CFR API Function calls.                                                    */
/*                                                                            */
/******************************************************************************/

#define E_OK                0x0000     /* No error occurred                   */
#define E_PARAM             0x0001     /* One or more parm. values is invalid */
#define E_END_OF_SCREEN     0x0002     /* Attempt to move past end of screen  */
#define E_CONTEXT           0x0003     /* Illegal context for call            */
#define E_GRAPHICS_ONLY     0x0004     /* Call valid only on Graphics model   */
#define E_NO_DATA           0x0005     /* No data available                   */
#define E_SPACE             0x0006     /* No space available                  */
#define E_DEVICE            0x0007     /* General device error                */
#define E_MEM               0x0008     /* Insufficient memory error           */
#define E_TCH_DATA          0x0009     /* More than 1 tch key pressed         */
#define E_DATA_NOT_FOUND    0x000A     /* Data not found in validation file   */
#define E_BUSY              0x000B     /* If the transaction buffer is busy   */
                                       /* (For example: waiting for host in   */
                                       /* interactive mode).                  */
#define E_HOST_DOWN         0x000C     /* The host did not respond to a       */
                                       /* remote validation request within    */
                                       /* the host timeout period.            */
#define E_NOT_PRESENT       0x000D     /* ESP or SP card is not present       */

#define E_INTERNAL          0xFFFF     /* Internal system error - Contact a   */
                                       /* Customer Service Representative     */


/******************************************************************************/
/*                                                                            */
/* The following definitions are the possible return codes from the CFR main  */
/* procedure that determine whether the calling transaction program will      */
/* abort, skip the next transaction program command, or continue.             */
/*                                                                            */
/******************************************************************************/

#define CONTINUE    0                  /* CFR ran successfully, continue with */
                                       /* the transaction program execution   */
#define NO_SKIP     0                  /* CFR ran successfully, continue with */
                                       /* the transaction program execution   */
#define SKIP        1                  /* CFR indicates that the next command */
                                       /* in the transaction program should   */
                                       /* be skipped over                     */
#define ABORT       2                  /* CFR did not run successfully, abort */
                                       /* the transaction program execution   */

/******************************************************************************/
/*                                                                            */
/* The following definitions are keyboard modes                               */
/*                                                                            */
/******************************************************************************/
#define OFF         0                  /* All keys passed directly to the CFR */
#define ON          1                  /* Adjustment keys handled automacally */


/******************************************************************************/
/*                                                                            */
/* The following definitions are keyboard scan codes used by the keyboard     */
/* related CFR API Function calls.                                            */
/*                                                                            */
/******************************************************************************/

#define CLEAR_KEY          0x0004
#define ENTER_KEY          0x000D
#define FILL_KEY           0x0005
#define SPACE_KEY          0x0020


/******************************************************************************/
/*                                                                            */
/* The following definitions are the date and time formats available in the   */
/* related CFR API Function calls.                                            */
/*                                                                            */
/******************************************************************************/

/******************************************************************************/
/* Date format values                                                         */
/******************************************************************************/
#define DEFAULT_DATE    0
#define MMDDYY          1
#define DDMMYY          2
#define YYMMDD          3
#define JJJYY           4
#define YYJJJ           5
#define MAX_DATE_VAL    5

/******************************************************************************/
/* Time format values                                                         */
/******************************************************************************/
#define DEFAULT_TIME    0
#define HHMMSS_12       1
#define HHMMSS_24       2
#define MAX_TIME_VAL    2

/******************************************************************************/
/*                                                                            */
/* These are constants which are passed to the Sensor subsystem APIs or       */
/* returned by them through return parameters.                                */
/*                                                                            */
/******************************************************************************/

/******************************************************************************/
/* These sensor port status definitions are returned by SenRead               */
/******************************************************************************/
#define UPC_A_READ              0  /* A UPC-A bar code has been scanned       */
#define UPC_E_READ              1  /* A UPC-E bar code has been scanned       */
#define EAN_13_READ             2  /* An EAN 13 bar code has been scanned     */
#define EAN_8_READ              3  /* An EAN 8 bar code has been scanned      */
#define CODE_39_READ            4  /* A Code 39 bar code has been scanned     */
#define I_25_CODE_READ          5  /* An I 2 of 5 bar code has been scanned   */
#define BAR_ERROR_READ          6  /* A bar code read error has been detected */
#define MAGNETIC_READ           7  /* A magnetic badge has been scanned       */
#define MAG_ERROR_READ          8  /* A magnetic read error has been detected */
#define CODABAR_READ            9  /* A CODABAR bar code has been scanned     */
#define CODE_11_READ           10  /* A Code 11 bar code has been scanned     */
#define MSI_CODE_READ          11  /* An MSI bar code has been scanned        */
#define CODE_128_READ          12  /* A Code 128 bar code has been scanned    */

/******************************************************************************/
/* These bar codes are passed to SenSetDiscrimGrp to enable the desired bar   */
/* code type to be read.                                                      */
/******************************************************************************/
#define UPC_ENABLED             0  /* Enable both UPC A and E                 */
#define EAN_ENABLED             1  /* Enable both EAN 8 and 16                */
#define CODE_39_ENABLED         2  /* Enable Code 39                          */
#define I_25_CODE_ENABLED       3  /* Enable I 2 of 5                         */
#define I_25_CHECK_CODE_ENABLED 4  /* Enable I 2 of 5 with check digit        */

/******************************************************************************/
/* Sensor port buffer port identifier codes                                   */
/******************************************************************************/
#define SEN_PORTA       0
#define SEN_PORTB       1
#define MAX_SEN_PORT    1

/******************************************************************************/
/* Sensor port read direction identifier codes                                */
/******************************************************************************/
#define FORWARD         0
#define BACKWARD        1
#define COPROCESSOR     2

/******************************************************************************/
/* Define sensor port LED codes                                               */
/******************************************************************************/

#define PANEL_LED_YELLOW  0
#define PANEL_LED_GREEN   1
#define MAG_PORTA_LED1    2
#define MAG_PORTA_LED2    3
#define MAG_PORTA_LED3    4
#define MAG_PORTB_LED1    5
#define MAG_PORTB_LED2    6
#define MAG_PORTB_LED3    7
#define MAX_LED_NUMBER    7


/******************************************************************************/
/*                                                                            */
/* These are manifest constants which are passed to SPK subsystem APIs.       */
/*                                                                            */
/******************************************************************************/

/******************************************************************************/
/* Values for volume                                                          */
/******************************************************************************/
#define  DEFAULT_VOLUME  0
#define  VOLUME_OFF      1
#define  VOLUME_LOW      2
#define  VOLUME_HIGH     3
#define  MAX_VOLUME_VAL  3


/******************************************************************************/
/*                                                                            */
/* These are manifest constants which are passed to VIO subsystem APIs or     */
/* returned by them through return parameters.                                */
/*                                                                            */
/******************************************************************************/

/******************************************************************************/
/* Screen positioning values                                                  */
/******************************************************************************/
#define CUR_ROW                 0xFF  /* Use current cusror row value         */
#define CUR_COL                 0xFF  /* Use current cursor column value      */

#define NO_CURSOR_MOVE          0x00  /* Cursor doesn't move during call      */
#define CURSOR_MOVE             0x01  /* Cursor moved to next pos. after call */
#define MAX_CURSOR_MOVE_VAL     0x01  /* Maximum value for this parameter     */

/******************************************************************************/
/* Video mode values (returned by VioQuery)                                   */
/******************************************************************************/
#define TWO_LINE_DISPLAY        0x00  /* Display H/W is 2L x 40C              */
#define ONE_LINE_DISPLAY        0x01  /* Display H/W is 1L x 16C              */

/******************************************************************************/
/* Cursor type values                                                         */
/******************************************************************************/
#define CURSOR_OFF                    0x00  /* Don't display cursor           */
#define CURSOR_UNDERBAR               0x01  /* Cursor as an underbar          */
#define CURSOR_UNDERBAR_BLINK_BLOCK   0x02  /* Blinking block, cursor underbar*/
#define CURSOR_BLINK_BLOCK            0x03  /* The whole block blinks         */

/******************************************************************************/
/* The following definitions are used with the DoWritePoint CFR API.          */
/******************************************************************************/
#define DO_CLEAR                0x00  /* Clear DO Point (output = 5 volts)    */
#define DO_SET                  0x01  /* Set DO Point (output = 0 volts       */
#define DO_TOGGLE               0x02  /* Toggle DO Point from previous value  */

/******************************************************************************/
/* The following definitions are used with the DoWritePoint CFR API.          */
/******************************************************************************/
#define AUTO_LINEFEED_ON        0x00  /* Enable automatic linefeeds           */
#define AUTO_LINEFEED_OFF       0x01  /* Disable automatic linefeeds          */

/******************************************************************************/
/* The following definitions are used with the Timer CFR APIs.                */
/******************************************************************************/
#define SUNDAY                  0x00  /* Sunday only                          */
#define MONDAY                  0x01  /* Monday only                          */
#define TUESDAY                 0x02  /* Tuesday only                         */
#define WEDNESDAY               0x03  /* Wednesday only                       */
#define THURSDAY                0x04  /* Thursday only                        */
#define FRIDAY                  0x05  /* Friday only                          */
#define SATURDAY                0x06  /* Saturday only                        */
#define EVERYDAY                0x07  /* Every day of the week                */
#define WEEKDAY                 0x08  /* Monday through Friday only           */

/******************************************************************************/
/* The following structures are used with the Timer CFR APIs.                 */
/******************************************************************************/

struct timer_alarms
{
 USHORT function;
 UCHAR  *parmstring;
 UCHAR  keydef;
 UCHAR  day;
 USHORT hour;
 USHORT minute;
 USHORT second;
 UCHAR  reserved[6];                             /* reserved                 */
};

struct timer_intervals
{
 USHORT function;
 UCHAR  *parmstring;
 USHORT interval;                                /* 20ms intervals           */
 UCHAR  keydef;
 UCHAR  reserved[3];                             /* reserved                 */
};

struct timer_alarms_asynch
{
 USHORT hour;
 USHORT minute;
 USHORT second;
 USHORT do_point;
 USHORT duration;                                /* 20ms period              */
 UCHAR  direction;                               /* 1 = on/off, 0 = off/on   */
 UCHAR  day;                                     /* Sunday = 0, Sat. = 6, 7,8*/
 UCHAR  reserved[4];                             /* reserved                 */
};

/******************************************************************************/
/*                                                                            */
/* Optional Serial-Parallel Card                                              */
/* Serial Port Modem Control defines                                          */
/*                                                                            */
/******************************************************************************/

/* Port number, as marked on the optional card's bracket */
#define SERIAL_1   1
#define SERIAL_2   2

/* For ComGetMdmCtl and ComSetMdmCtl */
#define MDM_DTR_LOW 0x80
#define MDM_DSR_LOW 0x40
#define MDM_CTS_LOW 0x20
#define MDM_DCD_LOW 0x08
#define MDM_RTS_LOW 0x02


/* For ComInit */
#define BAUD_110     0
#define BAUD_150     1
#define BAUD_300     2
#define BAUD_1200    3
#define BAUD_2400    4
#define BAUD_4800    5
#define BAUD_9600    6
#define BAUD_19200   7

/* For ComInit */
#define PARITY_NONE  0
#define PARITY_ODD   1
#define PARITY_EVEN  2

/* For ComInit */
#define STOP_BITS_1  1
#define STOP_BITS_2  2

/* For ComInit */
#define DATA_BITS_6  1
#define DATA_BITS_7  2
#define DATA_BITS_8  3

